@@ -10,7 +10,7 @@ from serde import deserialize
 from .s3 import write_file
 from .sink import Sink
 
-logger = logging.getLogger()
+logger = logging.getLogger(__name__)
 logger.setLevel(logging.INFO)
 
 
